@@ -930,6 +930,8 @@ class DebhelperBuildSystemRule(StepBasedBuildSystemRule):
         try:
             v = subprocess.check_output(
                 ["dh_assistant", "which-build-system"],
+                # Packages without `debhelper-compat` will trigger an error, which will just be noise
+                stderr=subprocess.DEVNULL,
                 cwd=source_root.fs_path,
             )
         except subprocess.CalledProcessError:
